# ServiceAccountStatus

The current status of the service account. The user field contains the user object corresponding to this service account. Users are then modified using the Users API.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**user** | [**UserIdentity**](UserIdentity.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


